@@ -16,14 +16,17 @@
 import os
 import subprocess
 import difflib
+import sys
 import time
+import ctypes
 import click
-from sys import platform, stderr
+from colorama import Fore
+from sys import platform
 from getpass import getpass, getuser
+from halo import Halo
 from progress.spinner import Spinner
 from progress.bar import IncrementalBar
 from subprocess import Popen, PIPE, DEVNULL, run
-from os import system
 from os.path import isfile
 from sys import platform
 from getpass import getuser
@@ -471,7 +474,6 @@ _______________________________
 | wireshark                   |
 | zoom                        |
 -------------------------------
-
 ____________________
 | Package           |
 ---------------------
@@ -508,7 +510,6 @@ ____________________
 | wget              |
 | yarn              |
 ---------------------
-
 _______________________________________________________________________
 | HyperPacks  |  Content                                              |
 -----------------------------------------------------------------------
@@ -658,8 +659,7 @@ class Updater:
                 version = line[1]
                 package_name = line[0]
                 if name == package_name:
-                    final = version
-                    return final
+                    return version
 
                 return
 
@@ -834,8 +834,7 @@ class Updater:
                 version = line[1]
                 package_name = line[0]
                 if name == package_name:
-                    final = version
-                    return final
+                    return version
 
                 return
 
@@ -990,7 +989,20 @@ class Updater:
 class Setup:
     def setup(self):
         user = getuser()
-        if platform == 'linux':
+        if platform == 'darwin':
+            # Installing and setting up Homebrew
+            click.echo(click.style(
+                'Setting Up Turbocharge on your Mac...', fg='green'))
+
+            os.system(
+                '/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)" < /dev/null')
+
+            file_exists = bool(isfile(f'/Users/{getuser()}/config.tcc'))
+            if not file_exists:
+                with open(f'/Users/{getuser()}/config.tcc', 'w+') as f:
+                    f.write(f'darwin\n{user}\n')
+
+        elif platform == 'linux':
             # Creating the config file
             setup_progress = IncrementalBar(
                 message='Setting Up Your Turbocharge Config...', max=100)
@@ -999,60 +1011,57 @@ class Setup:
                 setup_progress.next()
 
             file_exists = None
-            if isfile(f'/home/{getuser()}/config.tcc'):
-                file_exists = True
-            else:
-                file_exists = False
-
+            file_exists = bool(isfile(f'/home/{getuser()}/config.tcc'))
             if not file_exists:
                 with open(f'/home/{getuser()}/config.tcc', 'w+') as f:
                     f.write(f'linux\n{user}\n')
 
         elif platform == 'win32':
             # Install Chocolatey And Setup
-            setup_progress = Spinner(
-                'Setting up your Turbocharge config file...')
-            click.echo('\n')
-            for _ in range(1, 41):
-                sleep(0.02)
-                setup_progress.next()
+            home = os.path.expanduser('~')
+            
+            click.echo(click.style('Installing Chocolatey', 'green'))
+            if install_chocolatey():
+                click.echo('Successfully Installed Chocolatey')
+                with Halo(text='Setting Up Turbocharge Configuration ') as h:
+                    file_exists = None
+                    try:
+                        os.system(rf'mkdir {home}\Turbocharge')
+                    except:
+                        pass
+                    if isfile(os.path.join(rf"{home}\Turbocharge\config.tcc")):
+                        file_exists = True
+                    else:
+                        file_exists = False
 
-            file_exists = None
-            os.system(f'mkdir C:\\Users\\{getuser()}\Turbocharge')
-            if isfile(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc")):
-                file_exists = True
-            else:
-                file_exists = False
+                    if not file_exists:
+                        with open(os.path.join(rf"{home}\Turbocharge", "config.tcc"), 'w+') as f:
+                            f.write(f'win32\n{user}\n')
+                click.echo('Succesfully Setup Turbocharge!')
 
-            for _ in range(41, 61):
-                sleep(0.02)
-                setup_progress.next()
 
-            if not file_exists:
-                with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'w+') as f:
-                    f.write(f'win32\n{user}\n')
-            for _ in range(61, 100):
-                sleep(0.02)
-                setup_progress.next()
+ 
+def is_admin():
+    try:
+        is_admin = (os.getuid() == 0)
+    except AttributeError:
+        is_admin = ctypes.windll.shell32.IsUserAnAdmin() != 0
+    return is_admin
 
-        elif platform == 'darwin':
-            # Installing and setting up Homebrew
-            click.echo(click.style(
-                'Setting Up Turbocharge on your Mac...', fg='green'))
 
-            os.system(
-                '/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)" < /dev/null')
+def install_chocolatey():
+    home = os.path.expanduser('~')
+    if not is_admin():
+        click.echo(click.style('You Must Have Administrator Permissions To Install Chocolatey', 'red'), err=True)
+        sys.exit()
+    else:
+        os.system('powershell.exe -noprofile Set-ExecutionPolicy RemoteSigned -Scope CurrentUser')
+        with open(rf'{home}\temp.ps1', 'w+') as f:
+            f.write("Set-ExecutionPolicy Bypass -Scope Process -Force; [System.Net.ServicePointManager]::SecurityProtocol = [System.Net.ServicePointManager]::SecurityProtocol -bor 3072; iex ((New-Object System.Net.WebClient).DownloadString('https://chocolatey.org/install.ps1'))")
+        
+        ec = os.system(rf'powershell.exe -noprofile {home}\temp.ps1')
 
-            if isfile(f'/Users/{getuser()}/config.tcc'):
-                file_exists = True
-            else:
-                file_exists = False
-            if not file_exists:
-                with open(f'/Users/{getuser()}/config.tcc', 'w+') as f:
-                    f.write(f'darwin\n{user}\n')
-
-        click.echo('\n')
-        click.echo('Succesfully Setup Turbocharge!')
+    return ec == 0
 
 
 class Debugger:
@@ -1072,12 +1081,11 @@ class Debugger:
                     bold=True,
                     blink=True))
 
-            return
-
         else:
             click.echo(click.style(':( Failed To Debug... :(', fg='red'))
 
-            return
+
+        return
 
 
 class Installer:
@@ -1105,14 +1113,19 @@ class Installer:
                 package_name = line[0]
 
                 if name == package_name:
-                    final = version
-                    return final
+                    return version
 
                 return
 
         def subprocess_cmd(command):
-            process = subprocess.Popen(
-                command, stdout=subprocess.PIPE, stdin=PIPE, stderr=PIPE)
+            try:
+                process = subprocess.Popen(
+                    command, stdout=subprocess.PIPE, stdin=PIPE, stderr=PIPE)
+            except (OSError, PermissionError):
+                if platform == 'win32':
+                    click.echo('Please run electric as administrator!')
+                    os._exit(1)
+            
             proc_stdout = process.communicate()[0].strip()
             decoded = proc_stdout.decode("utf-8")
             version_tag = decoded.split("\n")[1]
@@ -1152,7 +1165,7 @@ class Installer:
                 if proc.returncode != 0:
                     click.echo(
                         click.style(
-                            '❎ Installation Failed... ❎',
+                            '❎ Installation Failed ❎',
                             fg='red',
                             blink=True,
                             bold=True))
@@ -1298,95 +1311,89 @@ class Installer:
 
             except subprocess.CalledProcessError as e:
                 click.echo(e.output)
-                click.echo('An Error Occured During Installation...', err=True)
+                click.echo('An Error Occured During Installation', err=True)
 
         elif platform == 'win32':
             try:
-                installer_progress = Spinner(
-                    message=f'Installing {package_name}...', max=100)
+                with Halo(text=f'Installing {package_name} ') as h:
+                    proc = Popen(script, stdout=PIPE, stderr=PIPE, stdin=PIPE, shell=True)  # first time
 
-                for _ in range(1, 75):
-                    time.sleep(0.01)
-                    installer_progress.next()
+                    proc.communicate()
+                    h.stop()
 
-                run(script, stdout=PIPE, stderr=PIPE)  # first time
+                    click.echo(
+                        click.style(
+                            f'\n\n 🎉 Successfully Installed {package_name}! 🎉 \n',
+                            fg='green',
+                            bold=True))
 
-                for _ in range(1, 25):
-                    time.sleep(0.01)
-                    installer_progress.next()
 
-                click.echo(
-                    click.style(
-                        f'\n\n 🎉 Successfully Installed {package_name}! 🎉 \n',
-                        fg='green',
-                        bold=True))
+                    testing_bar = IncrementalBar('Testing package...', max=100)
 
-                testing_bar = IncrementalBar('Testing package...', max=100)
+                    # this condition will be true for all applications
 
-                # this condition will be true for all applications
+                    if tests_passed == [] and test_script == '':
+                        # Dont run any tests, just exit
 
-                if tests_passed == [] and test_script == '':
-                    # Dont run any tests, just exit
+                        click.echo('\n')
+                        click.echo(
+                            click.style(
+                                f'Test Passed: {package_name} Launch ✅\n',
+                                fg='green'))
+
+                        return
+
+                    for _ in range(1, 64):
+                        time.sleep(0.002)
+                        testing_bar.next()
+
+                    run(test_script, stdout=PIPE, stderr=PIPE)
+
+                    in_app = get_key(package_name, applications_windows)
+                    in_dev = get_key(package_name, devpackages_windows)
+
+                    w_version = subprocess.Popen(
+                        "clist -l", stdin=PIPE, stderr=PIPE, stdout=PIPE)
+
+                    output = w_version.communicate()[0].decode()
+
+                    package_exists = False
+
+                    with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'r') as f:
+                        lines = f.readlines()
+
+                    for i in range(len(lines)):
+                        if (str(in_app) in lines[i]) or (str(in_dev) in lines[i]):
+                            package_exists = True
+                            break
+
+                    if not package_exists:
+                        if in_app != -1:
+                            version = getWinVer(output, in_app)
+                            with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'a+') as f:
+                                f.write(
+                                    f'{in_app} {version} a {0 if get_key(package_name, applications_windows)==-1 else 1} 1 {0 if get_key(package_name, applications_macos)==-1 else 1}\n')
+
+                        elif in_dev != -1:
+                            version = getWinVer(output, in_dev)
+                            with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'a+') as f:
+                                f.write(
+                                    f'{in_dev} {version} p {0 if get_key(package_name, devpackages_windows)==-1 else 1} 1 {0 if get_key(package_name, devpackages_macos)==-1 else 1}\n')
+
+                    for _ in range(64, 101):
+                        time.sleep(0.002)
+                        testing_bar.next()
 
                     click.echo('\n')
-                    click.echo(
-                        click.style(
-                            f'Test Passed: {package_name} Launch ✅\n',
-                            fg='green'))
+
+                    for test in tests_passed:
+                        click.echo(
+                            click.style(
+                                f'Test Passed: {test} ✅\n',
+                                fg='green'))
 
                     return
 
-                for _ in range(1, 64):
-                    time.sleep(0.002)
-                    testing_bar.next()
-
-                run(test_script, stdout=PIPE, stderr=PIPE)
-
-                in_app = get_key(package_name, applications_windows)
-                in_dev = get_key(package_name, devpackages_windows)
-
-                w_version = subprocess.Popen(
-                    "clist -l", stdin=PIPE, stderr=PIPE, stdout=PIPE)
-
-                output = w_version.communicate()[0].decode()
-
-                package_exists = False
-
-                with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'r') as f:
-                    lines = f.readlines()
-
-                for i in range(len(lines)):
-                    if (str(in_app) in lines[i]) or (str(in_dev) in lines[i]):
-                        package_exists = True
-                        break
-
-                if not package_exists:
-                    if in_app != -1:
-                        version = getWinVer(output, in_app)
-                        with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'a+') as f:
-                            f.write(
-                                f'{in_app} {version} a {0 if get_key(package_name, applications_windows)==-1 else 1} 1 {0 if get_key(package_name, applications_macos)==-1 else 1}\n')
-
-                    elif in_dev != -1:
-                        version = getWinVer(output, in_dev)
-                        with open(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc"), 'a+') as f:
-                            f.write(
-                                f'{in_dev} {version} p {0 if get_key(package_name, devpackages_windows)==-1 else 1} 1 {0 if get_key(package_name, devpackages_macos)==-1 else 1}\n')
-
-                for _ in range(64, 101):
-                    time.sleep(0.002)
-                    testing_bar.next()
-
-                click.echo('\n')
-
-                for test in tests_passed:
-                    click.echo(
-                        click.style(
-                            f'Test Passed: {test} ✅\n',
-                            fg='green'))
-
-                return
-
             except Exception as e:
                 click.echo(e)
                 click.echo('An Error Occured During Installation...', err=True)
@@ -1592,21 +1599,21 @@ def show_progress(finding_bar):
 
 def find(text):
     suggestions = []
-    if platform == 'linux':
+    if platform == 'darwin':
+        application_matches = difflib.get_close_matches(text, applications_macos)
+        package_matches = difflib.get_close_matches(text, devpackages_macos)
+        suggestions = application_matches + package_matches
+
+    elif platform == 'linux':
         application_matches = difflib.get_close_matches(text, applications_linux)
         package_matches = difflib.get_close_matches(text, devpackages_linux)
         suggestions = application_matches + package_matches
 
-    if platform == 'win32':
+    elif platform == 'win32':
         application_matches = difflib.get_close_matches(text, applications_windows)
         package_matches = difflib.get_close_matches(text, devpackages_windows)
         suggestions = application_matches + package_matches
 
-    if platform == 'darwin':
-        application_matches = difflib.get_close_matches(text, applications_macos)
-        package_matches = difflib.get_close_matches(text, devpackages_macos)
-        suggestions = application_matches + package_matches
-
     return suggestions
 
 
@@ -1854,7 +1861,8 @@ def cli(ctx):
             setup.setup()
 
     elif platform == 'win32':
-        if not isfile(os.path.join(f"C:\\Users\\{getuser()}\Turbocharge", "config.tcc")):
+        home = os.path.expanduser('~')
+        if not isfile(os.path.join(f"{home}\Turbocharge", "config.tcc")):
             setup.setup()
 
     elif platform == 'darwin':
@@ -1868,7 +1876,7 @@ def install(package_list):
     '''
     Install A Specified Package(s)
     '''
-    if platform == 'linux' or platform == 'darwin':
+    if platform in ['linux', 'darwin']:
         password = getpass('Enter your password: ')
     else:
         password = ''
@@ -1885,7 +1893,48 @@ def install(package_list):
     for package_name in packages:
         package_name = package_name.strip(' ')
 
-        if platform == 'linux':
+        if platform == 'darwin':
+            click.echo('\n')
+            finding_bar = IncrementalBar(
+                'Finding Requested Packages...', max=1)
+
+            if package_name in devpackages_macos:
+                show_progress(finding_bar)
+                turbocharge.install_task(
+                    package_name=devpackages_macos[package_name],
+                    script=f"brew install {package_name}",
+                    password="",
+                    test_script=f"{package_name} --version",
+                    tests_passed=[
+                        f'{devpackages_macos[package_name]} Version']
+                )
+                # test _scirpt is just a string here..
+
+            elif package_name in applications_macos:
+                show_progress(finding_bar)
+                turbocharge.install_task(
+                    package_name=applications_macos[package_name],
+                    script=f"brew cask install {package_name}",
+                    password="",
+                    test_script="",
+                    tests_passed=[]
+                )
+
+            else:
+                click.echo('\n')
+                click.echo(click.style(
+                    ':( Package Not Found! :( \n', fg='red'))
+                suggestions = find(package_name)
+                if suggestions != []:
+                    click.echo('\n')
+                    click.echo('Turbocharge found similar packages: \n')
+                    for suggestion in suggestions:
+                        click.echo(f'{suggestion} \n')
+                else:
+                    click.echo(
+                        'Turbocharge couldn\'t find similar packages...')
+
+        elif platform == 'linux':
             click.echo('\n')
             finding_bar = IncrementalBar(
                 'Finding Requested Packages...', max=1)
@@ -1927,12 +1976,12 @@ def install(package_list):
                             '\n Chrome Will Take 2 to 4 Minutes To Download... \n',
                             fg='yellow'))
 
-                    os.system(constant.chrome_link)
+                    os.system(chrome_link)
 
-                    os.system(constant.chrome_move)
+                    os.system(chrome_move)
 
                     second = Popen(
-                        constant.chrome_setup.split(),
+                        chrome_setup.split(),
                         stdin=PIPE,
                         stdout=PIPE,
                         stderr=PIPE
@@ -1977,18 +2026,18 @@ def install(package_list):
                     for _ in range(1, 35):
                         time.sleep(0.01)
                         installer_progress.next()
-                    os.system(constant.anaconda_download)
+                    os.system(anaconda_download)
                     for _ in range(35, 61):
                         time.sleep(0.01)
                         installer_progress.next()
 
-                    os.system(constant.anaconda_setup)
+                    os.system(anaconda_setup)
 
                     for _ in range(61, 91):
                         time.sleep(0.01)
                         installer_progress.next()
 
-                    os.system(constant.anaconda_PATH)
+                    os.system(anaconda_PATH)
 
                     for _ in range(90, 101):
                         time.sleep(0.01)
@@ -2011,15 +2060,15 @@ def install(package_list):
                     for _ in range(1, 35):
                         time.sleep(0.01)
                         installer_progress.next()
-                    os.system(constant.miniconda_download)
+                    os.system(miniconda_download)
                     for _ in range(35, 61):
                         time.sleep(0.01)
                         installer_progress.next()
-                    os.system(constant.miniconda_setup)
+                    os.system(miniconda_setup)
                     for _ in range(61, 91):
                         time.sleep(0.01)
                         installer_progress.next()
-                    os.system(constant.miniconda_PATH)
+                    os.system(miniconda_PATH)
                     for _ in range(90, 101):
                         time.sleep(0.01)
                         installer_progress.next()
@@ -2031,7 +2080,12 @@ def install(package_list):
                     click.echo(
                         'An Error Occurred During Installation...', err=True)
 
-            elif package_name not in devpackages_linux and package_name not in applications_linux and package_name != 'chrome' and package_name != 'anaconda' and package_name != 'miniconda':
+            elif (
+                package_name not in devpackages_linux
+                and package_name not in applications_linux
+                and package_name != 'chrome'
+                and package_name != 'anaconda'
+            ):
                 click.echo('\n')
                 click.echo(click.style(':( Package Not Found! :(', fg='red'))
                 suggestions = find(package_name)
@@ -2044,7 +2098,7 @@ def install(package_list):
                     click.echo(
                         'Turbocharge couldn\'t find similar packages...')
 
-        if platform == 'win32':
+        elif platform == 'win32':
             click.echo('\n')
             finding_bar = IncrementalBar(
                 'Finding Requested Packages...', max=1)
@@ -2071,7 +2125,7 @@ def install(package_list):
                     tests_passed=[]
                 )
 
-            elif package_name not in devpackages_windows and package_name not in applications_windows:
+            else:
                 click.echo('\n')
                 click.echo(click.style(':( Package Not Found! :(', fg='red'))
 
@@ -2085,47 +2139,6 @@ def install(package_list):
                     click.echo(
                         'Turbocharge couldn\'t find similar packages...')
 
-        if platform == 'darwin':
-            click.echo('\n')
-            finding_bar = IncrementalBar(
-                'Finding Requested Packages...', max=1)
-
-            if package_name in devpackages_macos:
-                show_progress(finding_bar)
-                turbocharge.install_task(
-                    package_name=devpackages_macos[package_name],
-                    script=f"brew install {package_name}",
-                    password="",
-                    test_script=f"{package_name} --version",
-                    tests_passed=[
-                        f'{devpackages_macos[package_name]} Version']
-                )
-                # test _scirpt is just a string here..
-
-            elif package_name in applications_macos:
-                show_progress(finding_bar)
-                turbocharge.install_task(
-                    package_name=applications_macos[package_name],
-                    script=f"brew cask install {package_name}",
-                    password="",
-                    test_script="",
-                    tests_passed=[]
-                )
-
-            elif package_name not in devpackages_macos and package_name not in applications_macos:
-                click.echo('\n')
-                click.echo(click.style(
-                    ':( Package Not Found! :( \n', fg='red'))
-                suggestions = find(package_name)
-                if suggestions != []:
-                    click.echo('\n')
-                    click.echo('Turbocharge found similar packages: \n')
-                    for suggestion in suggestions:
-                        click.echo(f'{suggestion} \n')
-                else:
-                    click.echo(
-                        'Turbocharge couldn\'t find similar packages...')
-
 
 @cli.command()
 @click.argument('package_list', required=True)
@@ -2135,7 +2148,7 @@ def remove(package_list):
     '''
     uninstaller = Uninstaller()
 
-    if platform == 'linux' or platform == 'darwin':
+    if platform in ['linux', 'darwin']:
         password = getpass('Enter your password: ')
     else:
         password = ''
@@ -2143,7 +2156,21 @@ def remove(package_list):
     packages = package_list.split(',')
 
     for package in packages:
-        if platform == 'linux':
+        if platform == 'darwin':
+            if package in devpackages_windows:
+                uninstaller.uninstall(
+                    f'brew uninstall {package}',
+                    password="",
+                    package_name=devpackages_macos[package]
+                )
+            elif package in applications_windows:
+                uninstaller.uninstall(
+                    f'brew cask uninstall {package}',
+                    password="",
+                    package_name=applications_macos[package]
+                )
+
+        elif platform == 'linux':
             if package in devpackages_linux:
                 uninstaller.uninstall(
                     f'{apt_remove} {package}',
@@ -2166,8 +2193,8 @@ def remove(package_list):
                         time.sleep(0.007)
                         installer_progress.next()
 
-                    os.system(constant.anaconda_remove_folder)
-                    os.system(constant.anaconda_remove_file)
+                    os.system(anaconda_remove_folder)
+                    os.system(anaconda_remove_file)
 
                     with open('.bashrc', 'r') as file:
                         lines = file.read()
@@ -2201,8 +2228,8 @@ def remove(package_list):
                         time.sleep(0.007)
                         installer_progress.next()
 
-                    os.system(constant.miniconda_remove_folder)
-                    os.system(constant.miniconda_remove_file)
+                    os.system(miniconda_remove_folder)
+                    os.system(miniconda_remove_file)
 
                     with open('.bashrc', 'r') as file:
                         lines = file.read()
@@ -2225,7 +2252,7 @@ def remove(package_list):
                     click.echo(
                         'An Error Occurred During Uninstallation...', err=True)
 
-        if platform == 'win32':
+        elif platform == 'win32':
             if package in devpackages_windows:
                 uninstaller.uninstall(
                     f'choco uninstall {package} --force -y',
@@ -2240,20 +2267,6 @@ def remove(package_list):
                     package_name=applications_windows[package]
                 )
 
-        if platform == 'darwin':
-            if package in devpackages_windows:
-                uninstaller.uninstall(
-                    f'brew uninstall {package}',
-                    password="",
-                    package_name=devpackages_macos[package]
-                )
-            elif package in applications_windows:
-                uninstaller.uninstall(
-                    f'brew cask uninstall {package}',
-                    password="",
-                    package_name=applications_macos[package]
-                )
-
 
 @cli.command()
 @click.argument('package_list', required=True)
@@ -2263,7 +2276,7 @@ def update(package_list):
     '''
     updater = Updater()
 
-    if platform == 'linux' or platform == 'darwin':
+    if platform in ['linux', 'darwin']:
         password = getpass('Enter your password: ')
     else:
         password = ''
@@ -2271,7 +2284,17 @@ def update(package_list):
     packages = package_list.split(',')
 
     for package in packages:
-        if platform == "linux":
+        if platform == "darwin":
+            if package in devpackages_macos:
+                updater.updatepack(package, password)
+
+            if package in applications_macos:
+                updater.updateapp(package, password)
+
+            else:
+                return
+
+        elif platform == "linux":
             if package in devpackages_linux:
                 updater.updatepack(package, password)
 
@@ -2280,7 +2303,7 @@ def update(package_list):
 
             else:
                 return
-        if platform == "win32":
+        elif platform == "win32":
             if package in devpackages_windows:
                 updater.updatepack(package, "")
 
@@ -2289,15 +2312,6 @@ def update(package_list):
 
             else:
                 return
-        if platform == "darwin":
-            if package in devpackages_macos:
-                updater.updatepack(package, password)
-
-            if package in applications_macos:
-                updater.updateapp(package, password)
-
-            else:
-                return
 
 
 @cli.command()
@@ -2317,7 +2331,7 @@ def hyperpack(hyperpack_list):
 
     password = ""
 
-    if platform == 'linux' or platform == 'darwin':
+    if platform in ['linux', 'darwin']:
         password = getpass('Enter your password: ')
         click.echo('\n')
 
@@ -2332,8 +2346,8 @@ def hyperpack(hyperpack_list):
         password_bar.next()
 
     click.echo('\n')
-    if platform == 'linux':
-        for hyperpack in hyperpacks:
+    for hyperpack in hyperpacks:
+        if platform == 'linux':
             hyper_pack = hyperpkgs[hyperpack]
 
             packages = hyper_pack.packages.split(',')
@@ -2366,8 +2380,7 @@ def hyperpack(hyperpack_list):
 
             cleaner.clean(password)
 
-    elif platform == 'win32':
-        for hyperpack in hyperpacks:
+        elif platform == 'win32':
             hyper_pack = hyperpkgs[hyperpack]
 
             packages = hyper_pack.packages.split(',')
@@ -2396,8 +2409,7 @@ def hyperpack(hyperpack_list):
 
             for app in apps:
                 updater.updateapp(app, password="")
-    elif platform == 'darwin':
-        for hyperpack in hyperpacks:
+        elif platform == 'darwin':
             hyper_pack = hyperpkgs[hyperpack]
 
             packages = hyper_pack.packages.split(',')
@@ -2447,12 +2459,12 @@ def clean():
     '''
     Remove Junk Packages Which Are Not Needed
     '''
-    if platform == 'linux':
+    if platform in ['linux', 'darwin']:
         uninstaller = Uninstaller()
         password = getpass('Enter your password: ')
         uninstaller.clean(password)
 
-    if platform == 'win32':
+    elif platform == 'win32':
         arr = ['|', "/", "-", "\\"]
 
         slen = len(arr)
@@ -2463,11 +2475,6 @@ def clean():
             time.sleep(0.04)
             print(arr[i % slen], end='\r')
 
-    elif platform == 'darwin':
-        uninstaller = Uninstaller()
-        password = getpass('Enter your password: ')
-        uninstaller.clean(password)
-
 
 @cli.command()
 def list():
@@ -2490,74 +2497,6 @@ def local():
     Lists all the installed packages.
     '''
 
-    if platform == 'linux':
-        packages = []
-        applications = []
-
-        lines = None
-
-        with open(f'/home/{getuser()}/config.tcc', 'r') as file:
-            lines = file.readlines()
-
-        for line in lines:
-            line = line.strip()
-            line.split()
-            try:
-                package_name = line.split()[0]
-            except IndexError:
-                continue
-            try:
-                package_type = line.split()[2]
-            except IndexError:
-                continue
-
-            if package_type == 'p':
-                packages.append(package_name)
-
-            if package_type == 'a':
-                applications.append(package_name)
-
-        click.clear()
-        click.echo('Packages : \n')
-
-        if packages != []:
-            for package in packages:
-                click.echo(package + '\n')
-
-        elif packages == []:
-            click.echo('Turbocharge couldn\'t find any packages installed.')
-
-        click.echo('Applications : \n')
-
-        if applications != []:
-            for app in applications:
-                click.echo(app + '\n')
-
-        elif applications == []:
-            click.echo(
-                'Turbocharge couldn\'t find any applications installed. \n')
-
-    if platform == 'win32':
-        packages = []
-
-        cmd = run('clist -l', stdout=PIPE, stderr=PIPE)
-
-        output = cmd.stdout.decode()
-
-        lines = output.split('\n')
-
-        for line in lines:
-            if not 'Chocolatey' in line and not 'chocolatey' in line and 'packages installed' not in line:
-                packages.append(line)
-
-        result = "Packages installed:\n"
-
-        for p in packages:
-            result += p
-            result += "\n"
-
-        click.echo(result)
-
     if platform == 'darwin':
         packages = []
         applications = []
@@ -2586,18 +2525,88 @@ def local():
 
         click.echo('Packages : \n')
 
-        if packages != []:
+        if packages == []:
+            click.echo('Turbocharge couldn\'t find any packages installed.')
+
+        else:
             for package in packages:
                 click.echo(package)
 
-        elif packages == []:
+        click.echo('Applications : \n')
+
+        if applications == []:
+            click.echo('Turbocharge couldn\'t find any applications installed.')
+        else:
+            for app in applications:
+                click.echo(app)
+
+    elif platform == 'linux':
+        packages = []
+        applications = []
+
+        lines = None
+
+        with open(f'/home/{getuser()}/config.tcc', 'r') as file:
+            lines = file.readlines()
+
+        for line in lines:
+            line = line.strip()
+            line.split()
+            try:
+                package_name = line.split()[0]
+            except IndexError:
+                continue
+            try:
+                package_type = line.split()[2]
+            except IndexError:
+                continue
+
+            if package_type == 'a':
+                applications.append(package_name)
+
+            elif package_type == 'p':
+                packages.append(package_name)
+
+        click.clear()
+        click.echo('Packages : \n')
+
+        if packages != []:
+            for package in packages:
+                click.echo(package + '\n')
+
+        else:
             click.echo('Turbocharge couldn\'t find any packages installed.')
 
         click.echo('Applications : \n')
 
-        if applications != []:
-            for app in applications:
-                click.echo(app)
+        if applications == []:
+            click.echo(
+                'Turbocharge couldn\'t find any applications installed. \n')
 
-        elif applications == []:
-            click.echo('Turbocharge couldn\'t find any applications installed.')
+        else:
+            for app in applications:
+                click.echo(app + '\n')
+
+    elif platform == 'win32':
+        cmd = run('clist -l', stdout=PIPE, stderr=PIPE)
+
+        output = cmd.stdout.decode()
+
+        lines = output.split('\n')
+
+        packages = [
+            line
+            for line in lines
+            if 'Chocolatey' not in line
+            and 'chocolatey' not in line
+            and 'packages installed' not in line
+        ]
+
+
+        result = "Packages installed:\n"
+
+        for p in packages:
+            result += p
+            result += "\n"
+
+        click.echo(result)
